@@ -41,6 +41,7 @@ struct _IBusM17NEngineClass {
     gint lookup_table_orientation;
     gboolean use_us_layout;
 
+    gchar *title;
     MInputMethod *im;
 };
 
@@ -105,9 +106,10 @@ ibus_m17n_scan_engine_name (const gchar *engine_name,
     gchar **strv;
 
     g_return_val_if_fail (g_str_has_prefix (engine_name, "m17n:"), FALSE);
-    strv = g_strsplit (engine_name, ":", 3);
+    /* Test engine name 'm17n:lang:layout:ci' works */
+    strv = g_strsplit (engine_name, ":", -1);
 
-    if (g_strv_length (strv) != 3) {
+    if (g_strv_length (strv) < 3) {
         g_strfreev (strv);
         g_return_val_if_reached (FALSE);
     }
@@ -236,10 +238,13 @@ ibus_m17n_engine_class_init (IBusM17NEngineClass *klass)
         "org.freedesktop.ibus.engine.m17n",
         g_strdup_printf ("/org/freedesktop/ibus/engine/m17n/%s/%s/",
                          lang, name));
+    MPlist *l = minput_get_title_icon (msymbol (lang), msymbol (name));
+    if (l && mplist_key (l) == Mtext) {
+        klass->title = ibus_m17n_mtext_to_utf8 (mplist_value (l));
+    }
+    engine_name = g_strdup_printf ("m17n:%s:%s", lang, name);
     g_free (lang);
     g_free (name);
-
-    engine_name = g_strdup_printf ("m17n:%s:%s", lang, name);
     engine_config = ibus_m17n_get_engine_config (engine_name);
     g_free (engine_name);
 
@@ -936,7 +941,12 @@ ibus_m17n_engine_callback (MInputContext *context,
     IBusM17NEngine *m17n = NULL;
 
     m17n = context->arg;
-    g_return_if_fail (m17n != NULL);
+    /* m17n always can be NULL when create_ic_for_im() calls minput_create_ic()
+     * in m17n-lib-1.8.0/src/input.c and g_return_if_fail() should not be
+     * called with CI since warnings are treated as errors.
+     */
+    if (!m17n)
+        return;
 
     /* the callback may be called in minput_create_ic, in the time
      * m17n->context has not be assigned, so need assign it. */
@@ -959,8 +969,9 @@ ibus_m17n_engine_callback (MInputContext *context,
     else if (command == Minput_status_draw) {
         gchar *status;
         status = ibus_m17n_mtext_to_utf8 (m17n->context->status);
+        IBusM17NEngineClass *klass = (IBusM17NEngineClass *) G_OBJECT_GET_CLASS (m17n);
 
-        if (status && strlen (status)) {
+        if (status && strlen (status) && g_strcmp0 (status, klass->title)) {
             IBusText *text;
             text = ibus_text_new_from_string (status);
             ibus_property_set_label (m17n->status_prop, text);
